==> react-head-1.4.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import { Title, HeadProvider, Link, Meta } from 'react-head';
import Body from './Body';
import Html from './Html';
export { HeadProvider };
/**
 * Extract value in a specific order
 * @param {{ name?: string, hreflang?: string, rel?: string , content?: string}} tag
 * @return {String}
 */

var extractKeyFromTag = function extractKeyFromTag(tag) {
  var name = tag.name,
      hreflang = tag.hreflang,
      rel = tag.rel,
      content = tag.content;
  return name || hreflang || rel || content;
};
/**
 * Filter children from React by tag type and return an array
 * @param {{ children: Array<React.ReactNode>, byTag: string }} params
 * @returns {Array}
 */


export var filter = function filter(_ref) {
  var children = _ref.children,
      byTag = _ref.byTag;
  return React.Children.toArray(children).filter(function (child) {
    return child.type === byTag;
  });
};
/**
 * Use the correct component to render the tag
 * @param {{ tagsArray: Array, Component: Object }} tagsArray
 * @returns {Array}
 */

var renderTags = function renderTags(_ref2) {
  var _ref2$tagsArray = _ref2.tagsArray,
      tagsArray = _ref2$tagsArray === void 0 ? [] : _ref2$tagsArray,
      Component = _ref2.Component;
  return tagsArray.map(function (tag) {
    var hrefLang = tag.hreflang,
        restOfTagInfo = _objectWithoutPropertiesLoose(tag, ["hreflang"]);

    return React.createElement(Component, Object.assign({
      key: extractKeyFromTag(tag),
      hrefLang: hrefLang
    }, restOfTagInfo));
  });
};
/**
 * Extract specific tags from children
 * @param {{
 *    children: Array<React.ReactNode>,
 *    tag: 'meta' | 'link' | 'title'
 *    fallback: Array
 *  }} params
 * @returns {Array}
 */


var extractTagsFrom = function extractTagsFrom(_ref3) {
  var children = _ref3.children,
      tag = _ref3.tag,
      fallback = _ref3.fallback;
  if (!children) return fallback;
  return filter({
    children: children,
    byTag: tag
  }).map(function (_ref4) {
    var props = _ref4.props;
    return _extends({}, props);
  });
};
/**
 * Extract title from children
 * @param {{ children: Array<React.ReactNode>, fallback: object }} params
 * @returns {String}
 */


var extractTitleFrom = function extractTitleFrom(_ref5) {
  var children = _ref5.children,
      fallback = _ref5.fallback;
  if (!children) return fallback;

  var _filter$map = filter({
    children: children,
    byTag: 'title'
  }).map(function (_ref6) {
    var props = _ref6.props;
    return props;
  }),
      title = _filter$map[0];

  return title ? title.children : fallback;
};

export default function Head(_ref7) {
  var bodyAttributes = _ref7.bodyAttributes,
      children = _ref7.children,
      htmlAttributes = _ref7.htmlAttributes,
      title = _ref7.title,
      _ref7$meta = _ref7.meta,
      meta = _ref7$meta === void 0 ? [] : _ref7$meta,
      _ref7$link = _ref7.link,
      link = _ref7$link === void 0 ? [] : _ref7$link;
  var metaTagsToRender = extractTagsFrom({
    children: children,
    tag: 'meta',
    fallback: meta
  });
  var linkTagsToRender = extractTagsFrom({
    children: children,
    tag: 'link',
    fallback: link
  }); // title is a special case, so we have the extract from the array
  // and simplify the fallback as used by the method

  var titleToRender = extractTitleFrom({
    children: children,
    fallback: title
  });
  return React.createElement(React.Fragment, null, titleToRender && React.createElement(Title, null, titleToRender), renderTags({
    tagsArray: metaTagsToRender,
    Component: Meta
  }), renderTags({
    tagsArray: linkTagsToRender,
    Component: Link
  }), bodyAttributes && React.createElement(Body, {
    attributes: bodyAttributes
  }), htmlAttributes && React.createElement(Html, {
    attributes: htmlAttributes
  }));
}

==> react-head-1.5.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import { Title, HeadProvider, Link, Meta } from 'react-head';
import Body from './Body';
import Html from './Html';
export { HeadProvider };
/**
 * Extract value in a specific order
 * @param {{ name?: string, hreflang?: string, rel?: string , content?: string}} tag
 * @return {String}
 */

var extractKeyFromTag = function extractKeyFromTag(tag) {
  var name = tag.name,
      hreflang = tag.hreflang,
      rel = tag.rel,
      content = tag.content;
  return name || hreflang || rel || content;
};
/**
 * Filter children from React by tag type and return an array
 * @param {{ children: Array<React.ReactNode>, byTag: string }} params
 * @returns {Array}
 */


export var filter = function filter(_ref) {
  var children = _ref.children,
      byTag = _ref.byTag;
  return React.Children.toArray(children).filter(function (child) {
    return child.type === byTag;
  });
};
/**
 * Use the correct component to render the tag
 * @param {{ tagsArray: Array, Component: Object }} tagsArray
 * @returns {Array}
 */

var renderTags = function renderTags(_ref2) {
  var _ref2$tagsArray = _ref2.tagsArray,
      tagsArray = _ref2$tagsArray === void 0 ? [] : _ref2$tagsArray,
      Component = _ref2.Component;
  return tagsArray.map(function (tag) {
    var hrefLang = tag.hreflang,
        restOfTagInfo = _objectWithoutPropertiesLoose(tag, ["hreflang"]);

    return /*#__PURE__*/_jsx(Component, _extends({
      hrefLang: hrefLang
    }, restOfTagInfo), extractKeyFromTag(tag));
  });
};
/**
 * Extract specific tags from children
 * @param {{
 *    children: Array<React.ReactNode>,
 *    tag: 'meta' | 'link' | 'title'
 *    fallback: Array
 *  }} params
 * @returns {Array}
 */


var extractTagsFrom = function extractTagsFrom(_ref3) {
  var children = _ref3.children,
      tag = _ref3.tag,
      fallback = _ref3.fallback;
  if (!children) return fallback;
  return filter({
    children: children,
    byTag: tag
  }).map(function (_ref4) {
    var props = _ref4.props;
    return _extends({}, props);
  });
};
/**
 * Extract title from children
 * @param {{ children: Array<React.ReactNode>, fallback: object }} params
 * @returns {String}
 */


var extractTitleFrom = function extractTitleFrom(_ref5) {
  var children = _ref5.children,
      fallback = _ref5.fallback;
  if (!children) return fallback;

  var _filter$map = filter({
    children: children,
    byTag: 'title'
  }).map(function (_ref6) {
    var props = _ref6.props;
    return props;
  }),
      title = _filter$map[0];

  return title ? title.children : fallback;
};

export default function Head(_ref7) {
  var bodyAttributes = _ref7.bodyAttributes,
      children = _ref7.children,
      htmlAttributes = _ref7.htmlAttributes,
      title = _ref7.title,
      _ref7$meta = _ref7.meta,
      meta = _ref7$meta === void 0 ? [] : _ref7$meta,
      _ref7$link = _ref7.link,
      link = _ref7$link === void 0 ? [] : _ref7$link;
  var metaTagsToRender = extractTagsFrom({
    children: children,
    tag: 'meta',
    fallback: meta
  });
  var linkTagsToRender = extractTagsFrom({
    children: children,
    tag: 'link',
    fallback: link
  }); // title is a special case, so we have the extract from the array
  // and simplify the fallback as used by the method

  var titleToRender = extractTitleFrom({
    children: children,
    fallback: title
  });
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [titleToRender && /*#__PURE__*/_jsx(Title, {
      children: titleToRender
    }), renderTags({
      tagsArray: metaTagsToRender,
      Component: Meta
    }), renderTags({
      tagsArray: linkTagsToRender,
      Component: Link
    }), bodyAttributes && /*#__PURE__*/_jsx(Body, {
      attributes: bodyAttributes
    }), htmlAttributes && /*#__PURE__*/_jsx(Html, {
      attributes: htmlAttributes
    })]
  });
}
